#!/bin/bash
# Copyright 2011 Adrian Reyer
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: bacula_schedule_special.sh,v 1.10 2011/07/17 20:06:42 are Exp $
#

usage () {
cat <<-'EOF'
	Bacula uses 'NextPool' for different things and you can't change it at
	runtime. A possible solution is to not schedule the jobs directly but
	schedule an AdminJob instead that changes the confuration temporarily
	while scheduling the real job

	--help -h	This text
	--job_next_pool_file	File containing the pool definition, only one pool may be defined within that file
	--job_next_pool		The NextPool valid for the jobs we start here
	--job			The job to start, seperate multiple jobs with (quoted) whitespace
	--cleanup_pool		The NextPool we set after we have scheduled the jobs
	--bconsole		bconsole binary, default is /usr/bin/bconsole
EOF
}


OPTIONS=`getopt -o h --long help,bconsole:,job_next_pool_file:,job_next_pool:,job:,cleanup_pool: -n "$0" -- "$@"`
if [ $? != 0 ] ; then
  usage >&2
  exit 1
fi
eval set -- "$OPTIONS"

BCONSOLE=/usr/bin/bconsole
while true; do
	case "$1" in
		-h|--help) usage; shift; exit 1 ;;
		--bconsole) BCONSOLE=$2; shift 2 ;;
		--job_next_pool_file) JOB_NEXT_POOL_FILE=$2; shift 2 ;;
		--job_next_pool) JOB_NEXT_POOL=$2; shift 2 ;;
		--job) JOB="$2"; shift 2 ;;
		--cleanup_pool) CLEANUP_POOL=$2; shift 2 ;;
		--) shift; break ;;
		*) echo $0 unrecognized option $1; usage >&2 ;;
	esac
done

change_next_pool() {
  BCONSOLE=$1
  FILE=$2
  POOL=$3
  sed -i 's/^[ \t]*NextPool[ \t]*=.*/  NextPool = '${POOL}'/' $FILE
  echo reload | $BCONSOLE
}

run_job() {
  BCONSOLE=$1
  JOB="$2"
  for job in $JOB; do
    echo run job=$job yes
  done | $BCONSOLE
}

if [ ga$JOB_NEXT_POOL_FILE != "ga" ]; then
  if [ ga$JOB_NEXT_POOL == ga ]; then
    echo "Need --job_next_pool with --job_next_pool_file"
    exit 1
  else
    if [ ga$CLEANUP_POOL == ga ]; then
      echo "Need --cleanup_pool with --job_next_pool"
      exit 1
    else
      change_next_pool "$BCONSOLE" "$JOB_NEXT_POOL_FILE" "$JOB_NEXT_POOL"
      run_job "$BCONSOLE" "$JOB"
      change_next_pool "$BCONSOLE" "$JOB_NEXT_POOL_FILE" "$CLEANUP_POOL"
    fi
  fi
else
  echo "Need --job_next_pool_file, we only change NextPool atm"
  exit 1
fi
